window.Gleam.initSearch([{"doc":"acrostic","title":"acrostic","content":"# acrostic\n\n[![Package Version](https://img.shields.io/hexpm/v/acrostic)](https://hex.pm/packages/acrostic)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/acrostic/)\n\nA pure Gleam implementation of Google Protobuf.\n\n\n## Note:\n\n1. only support proto3\n2. only support enum, message, repeated\n3. each message must have an annotation before it start\n\n    `// @gleam record` is mean a embedded struct (record)\n\n    `// @gleam msgid = 1` is mean a api, msgid is a big-end 2 bytes number (max is 65535)\n\n4. when you generated the `game.gleam`, the `game.encode(msg)` or `game.decode(binary)` all Assuming that the msgid is packaged in the head of binary (This will help with communication between the client and server)\n5. see `game.proto`\n\n\n\n## Useage:\n1. use `acrostic.gen` gen gleam file (eg: `src/game.gleam`) from proto files\n\n```sh\ngleam add acrostic\n```\n```gleam\nimport acrostic\n\npub fn main() {\n  acrostic.gen([&quot;game.proto&quot;], to: &quot;src/game.gleam&quot;, flags: acrostic.Flags(False, False))\n}\n```\n\n2. test encode/decode\n```gleam\nimport game\n\nlet binary = game.encode(\n    game.Test(\n      hello: &quot;hi&quot;,\n      world: 1.0,\n      item: game.Item(id:1, num:1),\n      pet: game.Cat,\n      nums: []\n    )\n  )\n\nlet assert Ok(test_msg) = game.decode(binary)\n\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/acrostic&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"acrostic","title":"Flags","content":"pub type Flags {\n  Flags(enum_to_int: Bool, int_to_enum: Bool)\n}\n\nFlags(enum_to_int: Bool, int_to_enum: Bool)\n\n\nSynonyms:\nacrostic.Flags\nacrostic Flags","url":"acrostic.html#Flags"},{"doc":"acrostic","title":"gen","content":"pub fn gen(\n  protos: List(String),\n  to out_path: String,\n  flags flags: Flags,\n) -&gt; Nil\n\nSynonyms:\nacrostic.gen\nacrostic gen","url":"acrostic.html#gen"},{"doc":"acrostic","title":"acrostic","content":"","url":"acrostic.html"},{"doc":"acrostic/wire","title":"WireType","content":"pub type WireType {\n  VarInt\n  I64\n  Len\n  I32\n}\n\nVarInt\n\n\nI64\n\n\nLen\n\n\nI32\n\n\nSynonyms:\nacrostic/wire.WireType\nacrostic/wire WireType","url":"acrostic/wire.html#WireType"},{"doc":"acrostic/wire","title":"from_int","content":"pub fn from_int(n: Int) -&gt; Result(WireType, String)\n\nSynonyms:\nacrostic/wire.from_int\nacrostic/wire from_int","url":"acrostic/wire.html#from_int"},{"doc":"acrostic/wire","title":"to_int","content":"pub fn to_int(wire: WireType) -&gt; Int\n\nSynonyms:\nacrostic/wire.to_int\nacrostic/wire to_int","url":"acrostic/wire.html#to_int"},{"doc":"acrostic/wire","title":"acrostic/wire","content":"","url":"acrostic/wire.html"},{"doc":"acrostic/decoding","title":"BasicDecoder","content":"pub type BasicDecoder(value) =\n  fn(BitArray) -&gt; Result(value, String)\n\n\nSynonyms:\nacrostic/decoding.BasicDecoder\nacrostic/decoding BasicDecoder","url":"acrostic/decoding.html#BasicDecoder"},{"doc":"acrostic/decoding","title":"FieldDecoder","content":"pub type FieldDecoder(value) {\n  FieldDecoder(wire_type: WireType, decode: BasicDecoder(value))\n}\n\nFieldDecoder(wire_type: WireType, decode: BasicDecoder(value))\n\n\nSynonyms:\nacrostic/decoding.FieldDecoder\nacrostic/decoding FieldDecoder","url":"acrostic/decoding.html#FieldDecoder"},{"doc":"acrostic/decoding","title":"Key","content":"pub type Key {\n  Key(field_number: Int, wire_type: WireType)\n}\n\nKey(field_number: Int, wire_type: WireType)\n\n\nSynonyms:\nacrostic/decoding.Key\nacrostic/decoding Key","url":"acrostic/decoding.html#Key"},{"doc":"acrostic/decoding","title":"bool_field_decoder","content":"pub const bool_field_decoder: FieldDecoder(Bool)\n\nSynonyms:\nacrostic/decoding.bool_field_decoder\nacrostic/decoding bool_field_decoder","url":"acrostic/decoding.html#bool_field_decoder"},{"doc":"acrostic/decoding","title":"i32_field_decoder","content":"pub const i32_field_decoder: FieldDecoder(Float)\n\nSynonyms:\nacrostic/decoding.i32_field_decoder\nacrostic/decoding i32_field_decoder","url":"acrostic/decoding.html#i32_field_decoder"},{"doc":"acrostic/decoding","title":"i64_field_decoder","content":"pub const i64_field_decoder: FieldDecoder(Float)\n\nSynonyms:\nacrostic/decoding.i64_field_decoder\nacrostic/decoding i64_field_decoder","url":"acrostic/decoding.html#i64_field_decoder"},{"doc":"acrostic/decoding","title":"int_field_decoder","content":"pub const int_field_decoder: FieldDecoder(Int)\n\nSynonyms:\nacrostic/decoding.int_field_decoder\nacrostic/decoding int_field_decoder","url":"acrostic/decoding.html#int_field_decoder"},{"doc":"acrostic/decoding","title":"string_field_decoder","content":"pub const string_field_decoder: FieldDecoder(String)\n\nSynonyms:\nacrostic/decoding.string_field_decoder\nacrostic/decoding string_field_decoder","url":"acrostic/decoding.html#string_field_decoder"},{"doc":"acrostic/decoding","title":"decode_field","content":"pub fn decode_field(\n  binary: BitArray,\n  wire_type: WireType,\n  decoder: FieldDecoder(a),\n) -&gt; Result(#(a, BitArray), String)\n\nSynonyms:\nacrostic/decoding.decode_field\nacrostic/decoding decode_field","url":"acrostic/decoding.html#decode_field"},{"doc":"acrostic/decoding","title":"decode_repeated_field","content":"pub fn decode_repeated_field(\n  binary: BitArray,\n  wire_type: WireType,\n  decoder: FieldDecoder(a),\n) -&gt; Result(#(List(a), BitArray), String)\n\nSynonyms:\nacrostic/decoding.decode_repeated_field\nacrostic/decoding decode_repeated_field","url":"acrostic/decoding.html#decode_repeated_field"},{"doc":"acrostic/decoding","title":"read_key","content":"pub fn read_key(\n  binary: BitArray,\n) -&gt; Result(#(Key, BitArray), String)\n\nSynonyms:\nacrostic/decoding.read_key\nacrostic/decoding read_key","url":"acrostic/decoding.html#read_key"},{"doc":"acrostic/decoding","title":"to_varint","content":"pub fn to_varint(binary: BitArray, acc: Int) -&gt; Int\n\nSynonyms:\nacrostic/decoding.to_varint\nacrostic/decoding to_varint","url":"acrostic/decoding.html#to_varint"},{"doc":"acrostic/decoding","title":"acrostic/decoding","content":"","url":"acrostic/decoding.html"},{"doc":"acrostic/encoding","title":"BasicEncoder","content":"pub type BasicEncoder(value) =\n  fn(value) -&gt; BitArray\n\n\nSynonyms:\nacrostic/encoding.BasicEncoder\nacrostic/encoding BasicEncoder","url":"acrostic/encoding.html#BasicEncoder"},{"doc":"acrostic/encoding","title":"FieldEncoder","content":"pub type FieldEncoder(value) {\n  FieldEncoder(wire_type: WireType, encode: BasicEncoder(value))\n}\n\nFieldEncoder(wire_type: WireType, encode: BasicEncoder(value))\n\n\nSynonyms:\nacrostic/encoding.FieldEncoder\nacrostic/encoding FieldEncoder","url":"acrostic/encoding.html#FieldEncoder"},{"doc":"acrostic/encoding","title":"bool_field_encoder","content":"pub const bool_field_encoder: FieldEncoder(Bool)\n\nSynonyms:\nacrostic/encoding.bool_field_encoder\nacrostic/encoding bool_field_encoder","url":"acrostic/encoding.html#bool_field_encoder"},{"doc":"acrostic/encoding","title":"i32_field_encoder","content":"pub const i32_field_encoder: FieldEncoder(Float)\n\nSynonyms:\nacrostic/encoding.i32_field_encoder\nacrostic/encoding i32_field_encoder","url":"acrostic/encoding.html#i32_field_encoder"},{"doc":"acrostic/encoding","title":"i64_field_encoder","content":"pub const i64_field_encoder: FieldEncoder(Float)\n\nSynonyms:\nacrostic/encoding.i64_field_encoder\nacrostic/encoding i64_field_encoder","url":"acrostic/encoding.html#i64_field_encoder"},{"doc":"acrostic/encoding","title":"int_field_encoder","content":"pub const int_field_encoder: FieldEncoder(Int)\n\nSynonyms:\nacrostic/encoding.int_field_encoder\nacrostic/encoding int_field_encoder","url":"acrostic/encoding.html#int_field_encoder"},{"doc":"acrostic/encoding","title":"string_field_encoder","content":"pub const string_field_encoder: FieldEncoder(String)\n\nSynonyms:\nacrostic/encoding.string_field_encoder\nacrostic/encoding string_field_encoder","url":"acrostic/encoding.html#string_field_encoder"},{"doc":"acrostic/encoding","title":"encode_bool","content":"pub fn encode_bool(b: Bool) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_bool\nacrostic/encoding encode_bool","url":"acrostic/encoding.html#encode_bool"},{"doc":"acrostic/encoding","title":"encode_field","content":"pub fn encode_field(\n  field_num: Int,\n  value: a,\n  encoder: FieldEncoder(a),\n) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_field\nacrostic/encoding encode_field","url":"acrostic/encoding.html#encode_field"},{"doc":"acrostic/encoding","title":"encode_i32","content":"pub fn encode_i32(n: Float) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_i32\nacrostic/encoding encode_i32","url":"acrostic/encoding.html#encode_i32"},{"doc":"acrostic/encoding","title":"encode_i64","content":"pub fn encode_i64(n: Float) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_i64\nacrostic/encoding encode_i64","url":"acrostic/encoding.html#encode_i64"},{"doc":"acrostic/encoding","title":"encode_repeated_field","content":"pub fn encode_repeated_field(\n  field_num: Int,\n  list: List(a),\n  encoder: FieldEncoder(a),\n) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_repeated_field\nacrostic/encoding encode_repeated_field","url":"acrostic/encoding.html#encode_repeated_field"},{"doc":"acrostic/encoding","title":"encode_string","content":"pub fn encode_string(s: String) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_string\nacrostic/encoding encode_string","url":"acrostic/encoding.html#encode_string"},{"doc":"acrostic/encoding","title":"encode_varint","content":"pub fn encode_varint(n: Int) -&gt; BitArray\n\nSynonyms:\nacrostic/encoding.encode_varint\nacrostic/encoding encode_varint","url":"acrostic/encoding.html#encode_varint"},{"doc":"acrostic/encoding","title":"acrostic/encoding","content":"","url":"acrostic/encoding.html"},{"doc":"acrostic/valid","title":"valid_int32","content":"pub fn valid_int32(n: Int, fallback: fn(Int, Int) -&gt; Int) -&gt; Int\n\nSynonyms:\nacrostic/valid.valid_int32\nacrostic/valid valid_int32","url":"acrostic/valid.html#valid_int32"},{"doc":"acrostic/valid","title":"valid_int64","content":"pub fn valid_int64(n: Int, fallback: fn(Int, Int) -&gt; Int) -&gt; Int\n\nSynonyms:\nacrostic/valid.valid_int64\nacrostic/valid valid_int64","url":"acrostic/valid.html#valid_int64"},{"doc":"acrostic/valid","title":"valid_uint32","content":"pub fn valid_uint32(n: Int, fallback: fn(Int, Int) -&gt; Int) -&gt; Int\n\nSynonyms:\nacrostic/valid.valid_uint32\nacrostic/valid valid_uint32","url":"acrostic/valid.html#valid_uint32"},{"doc":"acrostic/valid","title":"valid_uint64","content":"pub fn valid_uint64(n: Int, fallback: fn(Int, Int) -&gt; Int) -&gt; Int\n\nSynonyms:\nacrostic/valid.valid_uint64\nacrostic/valid valid_uint64","url":"acrostic/valid.html#valid_uint64"},{"doc":"acrostic/valid","title":"acrostic/valid","content":"","url":"acrostic/valid.html"}]);